﻿
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Documents;
using SecsTranslatorEditor.SecsLanguage.Formatters;

namespace SecsTranslatorEditor.SecsLanguage.Manual
{
	/// <summary>
	/// Represents a standard secs language syntax keyword.
	/// </summary>
	internal class SecsLanguageKeyword : ISecsLanguageSyntaxElement
	{
		#region Private Fields
		/// <summary>
		/// Represents the underlying keyword string representation. 
		/// </summary>
		private readonly string mKeyword;

		/// <summary>
		/// Represents the formatter used for visualizing the keyword.
		/// </summary>
		private readonly ISecsLanguageElementFormatter mFormatter;
		#endregion

		/// <summary>
		/// Gets a keyword string representation.
		/// </summary>
		public string Keyword => mKeyword;

		#region Constructors
		/// <summary>
		/// Initializes a new instance of the <see cref="SecsLanguageKeyword"/> class with a default formatter.
		/// </summary>
		/// <param name="keyword">The keyword's string representation.</param>
		internal SecsLanguageKeyword(string keyword)
		{
			mKeyword = keyword;
			mFormatter = new TypicalKeywordFormatter();
		}

		/// <summary>
		/// Initializes a new instance of the <see cref="SecsLanguageKeyword"/> class with an associated formatter.
		/// </summary>
		/// <param name="keyword">The keyword's string representation.</param>
		/// <param name="formatter">The keyword formatter.</param>
		internal SecsLanguageKeyword(string keyword, ISecsLanguageElementFormatter formatter)
		{
			mKeyword = keyword;
			mFormatter = formatter;
		}
		#endregion

		#region Public Methods
		/// <summary>
		/// Formats the provided Inline element.
		/// </summary>
		/// <param name="inline">The element that should be formatted.</param>
		/// <returns>The formatted Inline element.</returns>
		public Inline FormatInline(Inline inline)
		{
			return mFormatter.Format(inline);
		}

		/// <summary>
		/// Determines whether this element is the same as the provided one.
		/// </summary>
		/// <param name="element">The element that should be tested against.</param>
		/// <returns>Whether this element is the same as the provided or not.</returns>
		public bool IsMatch(string element)
		{
			return string.Equals(mKeyword, element, StringComparison.CurrentCultureIgnoreCase);
		}
		#endregion
	}
}
