﻿using System;
using System.Collections.ObjectModel;
using System.Windows;
using System.Windows.Input;
using SecsTranslatorEditor.Helpers;

namespace SecsTranslatorEditor.SecsLanguage
{
	/// <summary>Factory for constructing SECS translator editor dependency properties.</summary>
	internal static class SecsTranslatorEditorDependencyProperties
	{
		internal static DependencyProperty RegisterCaretPositionExternal(PropertyChangedCallback callback)
		{
			var metadata = new FrameworkPropertyMetadata(0,
				FrameworkPropertyMetadataOptions.AffectsMeasure |
				FrameworkPropertyMetadataOptions.AffectsRender |
				FrameworkPropertyMetadataOptions.BindsTwoWayByDefault |
				FrameworkPropertyMetadataOptions.Inherits,
				callback);

			return DependencyProperty.Register(
				"CaretPositionExternal", typeof(int), typeof(SecsTranslatorEditor), metadata);
		}

		internal static DependencyProperty RegisterIsReadOnly(Action<SecsTranslatorEditor, object> callback)
		{
			return DependencyProperty.Register(
				"IsReadOnly",
				typeof(bool),
				typeof(SecsTranslatorEditor),
				new UIPropertyMetadata(false, (d, e) => callback(d as SecsTranslatorEditor, e.NewValue)));
		}

		internal static DependencyProperty RegisterText(UIPropertyMetadata callback)
		{
			return DependencyProperty.Register(
				"Text",
				typeof(string),
				typeof(SecsTranslatorEditor),
				callback);
		}

		internal static DependencyProperty RegisterSearchPattern(Action<SecsTranslatorEditor, object> callback)
		{
			return DependencyProperty.Register(
				"SearchPattern",
				typeof(string),
				typeof(SecsTranslatorEditor),
				new UIPropertyMetadata(string.Empty, (d, e) => callback(d as SecsTranslatorEditor, e.NewValue)));
		}

		internal static DependencyProperty RegisterSearchResults()
		{
			return DependencyProperty.Register(
				"SearchResults",
				typeof(ObservableCollection<FindResultInfo>),
				typeof(SecsTranslatorEditor),
				new UIPropertyMetadata());
		}

		internal static DependencyProperty RegisterFindItem(Action<SecsTranslatorEditor, object> callback)
		{
			return DependencyProperty.Register(
				"FindItem",
				typeof(FindResultInfo),
				typeof(SecsTranslatorEditor),
				new UIPropertyMetadata(null, (d, e) => callback(d as SecsTranslatorEditor, e.NewValue)));
		}

		internal static DependencyProperty RegisterTextChangedCommand()
		{
			return DependencyProperty.Register(
				"TextChangedCommand",
				typeof(ICommand),
				typeof(SecsTranslatorEditor));
		}

		internal static DependencyProperty RegisterSelectTextPosition()
		{
			return DependencyProperty.Register("SelectTextPosition",
				typeof(string),
				typeof(SecsTranslatorEditor));
		}
	}
}
